@@ -3,7 +3,7 @@ BEGIN {
   $Dist::Zilla::PluginBundle::Author::DBR::AUTHORITY = 'cpan:DBR';
 }
 {
-  $Dist::Zilla::PluginBundle::Author::DBR::VERSION = '0.930';
+  $Dist::Zilla::PluginBundle::Author::DBR::VERSION = '1.0.0';
 } # Make CPAN happy
 
 #  PODNAME: Dist::Zilla::PluginBundle::Author::DBR
@@ -57,6 +57,7 @@ class Dist::Zilla::PluginBundle::Author::DBR
                 Test::MinimumVersion
                 Test::ReportPrereqs
                 Test::UseAllModules
+                Test::CPAN::Changes
                 TestRelease
 
             ],
@@ -107,7 +108,7 @@ Dist::Zilla::PluginBundle::Author::DBR - DBRs Dist::Zilla PluginBundle
 
 =head1 VERSION
 
-version 0.930
+version 1.0.0
 
 =head1 SYNOPSIS
 
@@ -122,12 +123,12 @@ This PluginBundle is roughly equivalent to the following C<dist.ini>:
     [Authority]
     authority        = cpan:DBR
 
-    [AutoMetaResources]
-    homepage            = https://metacpan.org/module/%{dist}
-    repository.type     = git
-    repository.url      = git://github.com/xdbr/%{dist}.git
-    repository.web      = http://github.com/xdbr/%{dist}
-    bugtracker.web      = http://github.com/xdbr/%{dist}/issues
+    ; [AutoMetaResources]
+    ; homepage            = https://metacpan.org/module/%{dist}
+    ; repository.type     = git
+    ; repository.url      = git://github.com/xdbr/%{dist}.git
+    ; repository.web      = http://github.com/xdbr/%{dist}
+    ; bugtracker.web      = http://github.com/xdbr/%{dist}/issues
 
 
     [@Git]
